@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 # Copyright 2016 99cloud
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -27,6 +25,11 @@ description:
   - A module targeting at collecting Docker container facts. It is used for
     detecting whether the container is running on host in Kolla.
 options:
+  container_engine:
+    description:
+      - Name of container engine to use
+    required: True
+    type: str
   api_version:
     description:
       - The version of the api for docker-py to use when contacting docker
@@ -49,6 +52,7 @@ EXAMPLES = '''
 
     - name: Gather glance container facts
       kolla_container_facts:
+        container_engine: docker
         name:
           - glance_api
           - glance_registry
@@ -62,7 +66,8 @@ def get_docker_client():
 def main():
     argument_spec = dict(
         name=dict(required=False, type='list', default=[]),
-        api_version=dict(required=False, type='str', default='auto')
+        api_version=dict(required=False, type='str', default='auto'),
+        container_engine=dict(required=True, type='str')
     )
 
     module = AnsibleModule(argument_spec=argument_spec)
